/* BDF - Copyright (c) 2009-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.servlets;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.interaction.Domains;
import java.io.IOException;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import net.mapeadores.util.servlets.HttpAccessException;
import net.mapeadores.util.servlets.HttpServletRequestMap;
import net.mapeadores.util.servlets.MultiPartParser;
import net.mapeadores.util.servlets.multipart.DefaultMultiPartParser;


/**
 *
 * @author Vincent Calame
 */
public class BDFServlet extends HttpServlet {

    private final MultiPartParser multiPartParser = new DefaultMultiPartParser();

    @Override
    public void doGet(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
        try {
            processRequest(request, response);
        } catch (HttpAccessException hae) {
            BDFUtils.sendError(request, response, hae);
        }
    }

    @Override
    public void doPost(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
        try {
            processRequest(request, response);
        } catch (HttpAccessException hae) {
            BDFUtils.sendError(request, response, hae);
        }
    }

    private void processRequest(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
        String pathInfo = request.getPathInfo();
        if (pathInfo == null) {
            throw new HttpAccessException(HttpAccessException.NOT_FOUND);
        }
        BDFWebapps bdfWebapps = (BDFWebapps) getServletContext().getAttribute(BDFWebapps.BDFWEBAPPS_KEY);
        if (pathInfo.equals("/")) {
            if (bdfWebapps.isMultiBdf()) {
                String fichothequeRedirect = BDFRoutes.getFichothequeRedirect(bdfWebapps.getMulti());
                if (fichothequeRedirect != null) {
                    BDFUtils.sendRedirect(response, fichothequeRedirect + "/" + Domains.SESSION);
                } else {
                    BDFUtils.sendRedirect(response, "multi-admin");
                }
            } else {
                BDFUtils.sendRedirect(response, Domains.SESSION);
            }
            return;
        }
        pathInfo = pathInfo.substring(1);
        HttpServletRequestMap requestMap = new HttpServletRequestMap(request, multiPartParser);
        if (bdfWebapps.isMultiBdf()) {
            BDFRoutes.resolveMulti(bdfWebapps, pathInfo, requestMap, response);
        } else {
            BdfServer bdfServer = bdfWebapps.getUnique().getBdfServer();
            BDFRoutes.resolveBdfServer(bdfWebapps, bdfServer, pathInfo, requestMap, response);
        }
    }

}
