/* BdfServer_Multi - Copyright (c) 2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.servlets;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.multi.api.Multi;
import fr.exemole.bdfserver.multi.tools.CrossInfo;
import net.fichotheque.SubsetKey;
import net.mapeadores.util.attr.Attribute;
import net.mapeadores.util.attr.AttributeKey;
import net.mapeadores.util.attr.CheckedNameSpace;
import net.mapeadores.util.servlets.HttpServletRequestMap;


/**
 *
 * @author Vincent Calame
 */
public class CrossInfoFactory {

    private final static CheckedNameSpace CROSSLOGIN_NAMESPACE = CheckedNameSpace.build("crosslogin");
    private final Multi multi;
    private final SubsetKey sphereKey;
    private final HttpServletRequestMap requestMap;


    private CrossInfoFactory(BDFWebapps bdfWebapps, SubsetKey sphereKey, HttpServletRequestMap requestMap) {
        this.multi = bdfWebapps.getMulti();
        this.sphereKey = sphereKey;
        this.requestMap = requestMap;
    }

    public static CrossInfo newInstance(BDFWebapps bdfWebapps, SubsetKey sphereKey, HttpServletRequestMap requestMap) {
        CrossInfoFactory factory = new CrossInfoFactory(bdfWebapps, sphereKey, requestMap);
        return factory.newInstance();
    }

    private CrossInfo newInstance() {
        String referenceFichothequeName = getReferenceFichothequeName();
        if (referenceFichothequeName == null) {
            throw new IllegalStateException("no referenceFichothequeName");
        }
        if (!multi.containsFichotheque(referenceFichothequeName)) {
            throw new IllegalStateException("Unknown referenceFichothequeName: " + referenceFichothequeName);
        }
        BdfUser bdfUser = null;
        if (multi.isInit(referenceFichothequeName)) {
            BdfServer bdfServer = multi.getBdfServer(referenceFichothequeName);
            bdfUser = BDFUtils.getCurrentBdfUser(bdfServer, requestMap.getRequest());
        }
        return new CrossInfo(sphereKey, referenceFichothequeName, bdfUser);

    }

    private String getReferenceFichothequeName() {
        AttributeKey attributeKey = AttributeKey.build(CROSSLOGIN_NAMESPACE, sphereKey.getSubsetName() + ":reference");
        Attribute attribute = multi.getMultiMetadata().getAttributes().getAttribute(attributeKey);
        if (attribute == null) {
            return null;
        }
        return attribute.getFirstValue();
    }

}
