/* BdfServer_JsonProducers - Copyright (c) 2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.jsonproducers.edition;

import fr.exemole.bdfserver.api.instruction.BdfCommandResult;
import fr.exemole.bdfserver.api.instruction.BdfInstructionConstants;
import fr.exemole.bdfserver.api.instruction.OutputParameters;
import fr.exemole.bdfserver.api.interaction.domains.EditionDomain;
import fr.exemole.bdfserver.jsonproducers.ResultJsonProducer;
import net.fichotheque.corpus.Corpus;
import net.fichotheque.corpus.fiche.FicheBlocks;
import net.mapeadores.util.json.JsonProducer;
import net.mapeadores.util.json.JsonProperty;
import net.mapeadores.util.localisation.MessageLocalisation;
import net.mapeadores.util.logging.ErrorMessageException;


/**
 *
 * @author Vincent Calame
 */
public final class EditionJsonProducerFactory {

    private EditionJsonProducerFactory() {

    }

    public static JsonProducer getJsonProducer(OutputParameters parameters) throws ErrorMessageException {
        String json = parameters.getOutput();
        BdfCommandResult bdfCommandResult = parameters.getBdfCommandResult();
        JsonProperty jsonProperty = null;
        MessageLocalisation messageLocalisation = parameters.getMessageLocalisation();
        switch (json) {
            case EditionDomain.SECTION_JSON:
                if (bdfCommandResult != null) {
                    FicheBlocks ficheBlocks = (FicheBlocks) bdfCommandResult.getResultObject(BdfInstructionConstants.FICHEBLOCKS_OBJ);
                    Corpus corpus = (Corpus) bdfCommandResult.getResultObject(BdfInstructionConstants.CORPUS_OBJ);
                    if ((ficheBlocks != null) && (corpus != null)) {
                        jsonProperty = new SectionHtmlJsonProperty(parameters, corpus, ficheBlocks);
                    }
                }
                break;
        }
        if (jsonProperty != null) {
            ResultJsonProducer jsonProducer = new ResultJsonProducer(bdfCommandResult, messageLocalisation);
            jsonProducer.add(jsonProperty);
            return jsonProducer;
        } else {
            return null;
        }
    }

}
