/* BdfServer_JsonProducers - Copyright (c) 2017-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.jsonproducers.thesaurus;

import java.io.IOException;
import java.util.List;
import net.fichotheque.exportation.table.CellEngine;
import net.fichotheque.json.CellJson;
import net.fichotheque.thesaurus.Motcle;
import net.fichotheque.thesaurus.Thesaurus;
import net.mapeadores.util.json.JSONWriter;
import net.mapeadores.util.json.JsonProperty;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.text.Label;
import net.mapeadores.util.text.LabelUtils;


/**
 *
 * @author Vincent Calame
 */
public class ThesaurusJsonProperty implements JsonProperty {

    private final Thesaurus thesaurus;
    private final Lang lang;
    private final CellEngine cellEngine;

    public ThesaurusJsonProperty(Thesaurus thesaurus, Lang lang, CellEngine cellEngine) {
        this.thesaurus = thesaurus;
        this.lang = lang;
        this.cellEngine = cellEngine;
    }

    @Override
    public void write(JSONWriter jw) throws IOException {
        jw.key("thesaurus");
        jw.object();
        {
            jw.key("name")
                    .value(thesaurus.getSubsetKey().getSubsetName());
            jw.key("firstLevelArray");
            writeMotcleList(jw, thesaurus.getFirstLevelList());
        }
        jw.endObject();
    }

    private void writeMotcleList(JSONWriter jw, List<Motcle> motcleList) throws IOException {
        jw.array();
        for (Motcle motcle : motcleList) {
            jw.object();
            {
                jw.key("id")
                        .value(motcle.getId());
                String idalpha = motcle.getIdalpha();
                if (idalpha != null) {
                    jw.key("idalpha")
                            .value(idalpha);
                }
                Label label = LabelUtils.getLangPartCheckedLabel(motcle.getLabels(), lang);
                String title = "";
                if (label != null) {
                    title = label.getLabelString();
                }
                jw.key("title")
                        .value(title);
                CellJson.cellArrayMappingProperty(jw, cellEngine.getCellArray(motcle));
                jw.key("childArray");
                writeMotcleList(jw, motcle.getChildList());
            }
            jw.endObject();
        }
        jw.endArray();
    }

}
